commit d0bdd0d7a768f9935b521f3bd12a4cd72739b96f
Author: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date:   1324253323 -0600

    Rename old tq methods that no longer need a unique name

diff --git a/src/app/bookmarkdialogbase.ui b/src/app/bookmarkdialogbase.ui
index d4db944..08ccea2 100644
--- a/src/app/bookmarkdialogbase.ui
+++ b/src/app/bookmarkdialogbase.ui
@@ -20,7 +20,7 @@
             <verstretch>0</verstretch>
         </sizepolicy>
     </property>
-    <property name="tqminimumSize">
+    <property name="minimumSize">
         <size>
             <width>400</width>
             <height>0</height>
@@ -88,7 +88,7 @@
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>383</width>
                     <height>16</height>
diff --git a/src/app/bookmarkviewcontroller.cpp b/src/app/bookmarkviewcontroller.cpp
index b40f70e..68ee9f0 100644
--- a/src/app/bookmarkviewcontroller.cpp
+++ b/src/app/bookmarkviewcontroller.cpp
@@ -98,7 +98,7 @@ public:
 		if ( !item) return;
 		if (item->mBookmark.isGroup()) return;
 		
-		TQRect rect=mListView->tqitemRect(item);
+		TQRect rect=mListView->itemRect(item);
 		tip(rect, item->mBookmark.url().prettyURL());
 	};
 	
diff --git a/src/app/configdialog.cpp b/src/app/configdialog.cpp
index 0fb33df..d274188 100644
--- a/src/app/configdialog.cpp
+++ b/src/app/configdialog.cpp
@@ -289,7 +289,7 @@ void ConfigDialog::emptyCache() {
 
 	KURL url;
 	url.setPath(dir);
-	if (KIO::NetAccess::del(url, tqtopLevelWidget()) ) {
+	if (KIO::NetAccess::del(url, topLevelWidget()) ) {
 		KMessageBox::information( this,i18n("Cache emptied.") );
 	}
 }
diff --git a/src/app/configfileoperationspage.ui b/src/app/configfileoperationspage.ui
index 78ac6d3..451a030 100644
--- a/src/app/configfileoperationspage.ui
+++ b/src/app/configfileoperationspage.ui
@@ -93,7 +93,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>16</height>
diff --git a/src/app/configfullscreenpage.ui b/src/app/configfullscreenpage.ui
index e7da709..855869f 100644
--- a/src/app/configfullscreenpage.ui
+++ b/src/app/configfullscreenpage.ui
@@ -43,7 +43,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>16</height>
@@ -131,7 +131,7 @@ You can use the following keywords to format the On Screen Display:
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>18</height>
diff --git a/src/app/configimagelistpage.ui b/src/app/configimagelistpage.ui
index 6670dbd..e2fb15b 100644
--- a/src/app/configimagelistpage.ui
+++ b/src/app/configimagelistpage.ui
@@ -40,7 +40,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>16</height>
@@ -131,7 +131,7 @@
                     <property name="sizeType">
                         <enum>Expanding</enum>
                     </property>
-                    <property name="tqsizeHint">
+                    <property name="sizeHint">
                         <size>
                             <width>20</width>
                             <height>0</height>
@@ -166,7 +166,7 @@
                     <property name="sizeType">
                         <enum>Fixed</enum>
                     </property>
-                    <property name="tqsizeHint">
+                    <property name="sizeHint">
                         <size>
                             <width>21</width>
                             <height>20</height>
@@ -217,7 +217,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>16</height>
diff --git a/src/app/configimageviewpage.ui b/src/app/configimageviewpage.ui
index a99b945..32fb346 100644
--- a/src/app/configimageviewpage.ui
+++ b/src/app/configimageviewpage.ui
@@ -56,7 +56,7 @@
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>181</width>
                     <height>21</height>
@@ -238,7 +238,7 @@ Use this option if your computer is not very fast.</string>
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>16</height>
diff --git a/src/app/configmiscpage.ui b/src/app/configmiscpage.ui
index 9b69c2d..9df8e96 100644
--- a/src/app/configmiscpage.ui
+++ b/src/app/configmiscpage.ui
@@ -92,7 +92,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>20</width>
                     <height>24</height>
@@ -120,7 +120,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>20</width>
                     <height>24</height>
@@ -153,7 +153,7 @@
                     <property name="sizeType">
                         <enum>Fixed</enum>
                     </property>
-                    <property name="tqsizeHint">
+                    <property name="sizeHint">
                         <size>
                             <width>11</width>
                             <height>20</height>
@@ -191,7 +191,7 @@
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>41</height>
diff --git a/src/app/configslideshowpage.ui b/src/app/configslideshowpage.ui
index 62ab807..ccf0c15 100644
--- a/src/app/configslideshowpage.ui
+++ b/src/app/configslideshowpage.ui
@@ -88,7 +88,7 @@ When this option is enabled, the slideshow will stop on the last image of the fo
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>180</width>
                     <height>20</height>
diff --git a/src/app/mainwindow.cpp b/src/app/mainwindow.cpp
index 1464a09..f9acc9b 100644
--- a/src/app/mainwindow.cpp
+++ b/src/app/mainwindow.cpp
@@ -871,7 +871,7 @@ void MainWindow::createWidgets() {
 	tqlayout->setAutoAdd(true);
 	mCentralStack->addWidget(mViewModeWidget);
 
-	// tqStatus bar
+	// Status bar
 	mSBDetailLabel=new TQLabel("", statusBar());
 	
 	mSBHintLabel=new TruncatedTextLabel(statusBar());
@@ -1216,7 +1216,7 @@ void MainWindow::createLocationToolBar() {
 
 	// Do not let the combobox get wider than available space, as this would
 	// hide the toolbuttons after it
-	mURLEdit->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed);
+	mURLEdit->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed);
 	
 	// Avoid stealing focus
 	mURLEdit->setFocusPolicy(TQ_ClickFocus);
diff --git a/src/app/truncatedtextlabel.h b/src/app/truncatedtextlabel.h
index 8e126ed..2351890 100644
--- a/src/app/truncatedtextlabel.h
+++ b/src/app/truncatedtextlabel.h
@@ -39,14 +39,14 @@ public:
 	TruncatedTextLabel(TQWidget* parent)
 	: TQLabel(parent) {}
 
-	TQSize tqminimumSizeHint() const {
-		TQSize size=TQLabel::tqminimumSizeHint();
+	TQSize minimumSizeHint() const {
+		TQSize size=TQLabel::minimumSizeHint();
 		size.setWidth(-1);
 		return size;
 	}
 
-	TQSize tqsizeHint() const {
-		return TQSize(contentsRect().width(), TQLabel::tqsizeHint().height());
+	TQSize sizeHint() const {
+		return TQSize(contentsRect().width(), TQLabel::sizeHint().height());
 	}
 
 	void setText(const TQString& text) {
diff --git a/src/gvcore/cursortracker.cpp b/src/gvcore/cursortracker.cpp
index 00f1736..3569dc8 100644
--- a/src/gvcore/cursortracker.cpp
+++ b/src/gvcore/cursortracker.cpp
@@ -79,7 +79,7 @@ TipTracker::TipTracker(const TQString& txt, TQWidget* reference)
 	setPalette(TQToolTip::palette());
 	setFrameStyle(TQFrame::Plain | TQFrame::Box);
 	setLineWidth(1);
-	tqsetAlignment(AlignAuto | AlignTop);
+	setAlignment(AlignAuto | AlignTop);
 }
 	
 
diff --git a/src/gvcore/deletedialog.cpp b/src/gvcore/deletedialog.cpp
index 3d6308b..9fdfac5 100644
--- a/src/gvcore/deletedialog.cpp
+++ b/src/gvcore/deletedialog.cpp
@@ -113,9 +113,9 @@ bool DeleteDialog::shouldDelete() const {
 }
 
 
-TQSize DeleteDialog::tqsizeHint() const {
+TQSize DeleteDialog::sizeHint() const {
     m_widget->adjustSize();
-    TQSize hint = m_widget->tqminimumSize();
+    TQSize hint = m_widget->minimumSize();
     hint = calculateSize(hint.width(), hint.height());
 
     // For some reason calculateSize does not return a correct height. As I'm
diff --git a/src/gvcore/deletedialog.h b/src/gvcore/deletedialog.h
index 6825368..1bdc5ab 100644
--- a/src/gvcore/deletedialog.h
+++ b/src/gvcore/deletedialog.h
@@ -36,7 +36,7 @@ public:
     void setURLList(const KURL::List &files);
     bool shouldDelete() const;
 
-    TQSize tqsizeHint() const;
+    TQSize sizeHint() const;
 
 protected slots:
     virtual void accept();
diff --git a/src/gvcore/deletedialogbase.ui b/src/gvcore/deletedialogbase.ui
index 4725920..6abab10 100644
--- a/src/gvcore/deletedialogbase.ui
+++ b/src/gvcore/deletedialogbase.ui
@@ -47,7 +47,7 @@
                     <property name="name">
                         <cstring>ddDeleteText</cstring>
                     </property>
-                    <property name="tqminimumSize">
+                    <property name="minimumSize">
                         <size>
                             <width>0</width>
                             <height>60</height>
diff --git a/src/gvcore/externaltooldialogbase.ui b/src/gvcore/externaltooldialogbase.ui
index 00d2954..2c25a92 100644
--- a/src/gvcore/externaltooldialogbase.ui
+++ b/src/gvcore/externaltooldialogbase.ui
@@ -20,7 +20,7 @@
             <verstretch>0</verstretch>
         </sizepolicy>
     </property>
-    <property name="tqminimumSize">
+    <property name="minimumSize">
         <size>
             <width>720</width>
             <height>0</height>
@@ -49,7 +49,7 @@
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>487</width>
                     <height>16</height>
@@ -304,7 +304,7 @@ You can use keywords in the Command field:
                             <property name="sizeType">
                                 <enum>Expanding</enum>
                             </property>
-                            <property name="tqsizeHint">
+                            <property name="sizeHint">
                                 <size>
                                     <width>21</width>
                                     <height>140</height>
diff --git a/src/gvcore/filedetailview.cpp b/src/gvcore/filedetailview.cpp
index f061c13..a8eba49 100644
--- a/src/gvcore/filedetailview.cpp
+++ b/src/gvcore/filedetailview.cpp
@@ -125,8 +125,8 @@ FileDetailView::FileDetailView(TQWidget *parent, const char *name)
 	setDropHighlighter(false);
 
 	int size = IconSize(KIcon::Small);
-	mShownItemUnselectedPixmap = createShownItemPixmap(size, tqcolorGroup().highlight());
-	mShownItemSelectedPixmap = createShownItemPixmap(size, tqcolorGroup().highlightedText());
+	mShownItemUnselectedPixmap = createShownItemPixmap(size, colorGroup().highlight());
+	mShownItemSelectedPixmap = createShownItemPixmap(size, colorGroup().highlightedText());
 }
 
 
diff --git a/src/gvcore/filedetailviewitem.h b/src/gvcore/filedetailviewitem.h
index 1104bce..a0ad5df 100644
--- a/src/gvcore/filedetailviewitem.h
+++ b/src/gvcore/filedetailviewitem.h
@@ -71,7 +71,7 @@ public:
 
 	TQRect rect() const
 	{
-		TQRect r = listView()->tqitemRect(this);
+		TQRect r = listView()->itemRect(this);
 		return TQRect( listView()->viewportToContents( r.topLeft() ),
 					  TQSize( r.width(), r.height() ) );
 	}
diff --git a/src/gvcore/fileopobject.cpp b/src/gvcore/fileopobject.cpp
index e72d192..9f09438 100644
--- a/src/gvcore/fileopobject.cpp
+++ b/src/gvcore/fileopobject.cpp
@@ -89,7 +89,7 @@ void FileOpObject::slotResult(KIO::Job* job) {
 
 
 void FileOpObject::polishJob(KIO::Job* job) {
-	job->setWindow(mParent->tqtopLevelWidget());
+	job->setWindow(mParent->topLevelWidget());
 	connect( job, TQT_SIGNAL( result(KIO::Job*) ),
 		this, TQT_SLOT( slotResult(KIO::Job*) ) );
 }
diff --git a/src/gvcore/filethumbnailview.cpp b/src/gvcore/filethumbnailview.cpp
index 51445be..3910e48 100644
--- a/src/gvcore/filethumbnailview.cpp
+++ b/src/gvcore/filethumbnailview.cpp
@@ -93,7 +93,7 @@ public:
 	
 	void polish() {
 		TQFrame::polish();
-		setMinimumWidth(tqlayout()->tqminimumSize().width());
+		setMinimumWidth(tqlayout()->minimumSize().width());
 		//setFixedHeight( mProgressBar->height() );
 		setFixedHeight( mStop->height() );
 	}
@@ -142,7 +142,7 @@ struct FileThumbnailView::Private {
 		mWaitThumbnail.fill(view->paletteBackgroundColor());
 		TQPainter painter(&mWaitThumbnail);
 		
-		painter.setPen(view->tqcolorGroup().button());
+		painter.setPen(view->colorGroup().button());
 		painter.drawRect(0,0,mThumbnailSize,mThumbnailSize);
 		painter.drawPixmap(
 			(mThumbnailSize-mWaitPixmap.width())/2,
diff --git a/src/gvcore/filethumbnailviewitem.cpp b/src/gvcore/filethumbnailviewitem.cpp
index 65da494..cd607b7 100644
--- a/src/gvcore/filethumbnailviewitem.cpp
+++ b/src/gvcore/filethumbnailviewitem.cpp
@@ -271,16 +271,16 @@ void FileThumbnailViewItem::calcRect(const TQString&) {
 		textH+=(*it)->height();
 	}
 	
-	TQRect tqitemRect(x(), y(), view->gridX(), 0);
+	TQRect itemRect(x(), y(), view->gridX(), 0);
 	TQRect itemPixmapRect(PADDING, PADDING, thumbnailSize, thumbnailSize);
 	TQRect itemTextRect(0, 0, textW, textH);
 	if (isRight) {
-		tqitemRect.setHeight( TQMAX(thumbnailSize + PADDING*2, textH) );
+		itemRect.setHeight( TQMAX(thumbnailSize + PADDING*2, textH) );
 		itemTextRect.moveLeft(thumbnailSize + PADDING * 2 );
-		itemTextRect.moveTop((tqitemRect.height() - textH)/2);
+		itemTextRect.moveTop((itemRect.height() - textH)/2);
 	} else {
-		itemPixmapRect.moveLeft( (tqitemRect.width() - itemPixmapRect.width()) / 2 );
-		tqitemRect.setHeight(thumbnailSize + PADDING*3 + textH);
+		itemPixmapRect.moveLeft( (itemRect.width() - itemPixmapRect.width()) / 2 );
+		itemRect.setHeight(thumbnailSize + PADDING*3 + textH);
 		itemTextRect.moveLeft(PADDING);
 		itemTextRect.moveTop(thumbnailSize + PADDING * 2);
 	}
@@ -292,8 +292,8 @@ void FileThumbnailViewItem::calcRect(const TQString&) {
 	if ( itemTextRect != textRect() ) {
 		setTextRect( itemTextRect );
 	}
-	if ( tqitemRect != rect() ) {
-		setItemRect( tqitemRect );
+	if ( itemRect != rect() ) {
+		setItemRect( itemRect );
 	}
 }
 
diff --git a/src/gvcore/filethumbnailviewitem.h b/src/gvcore/filethumbnailviewitem.h
index b242355..d3a1063 100644
--- a/src/gvcore/filethumbnailviewitem.h
+++ b/src/gvcore/filethumbnailviewitem.h
@@ -52,7 +52,7 @@ public:
 	void updateLines();
 
 protected:
-	void paintItem(TQPainter* painter, const TQColorGroup& tqcolorGroup);
+	void paintItem(TQPainter* painter, const TQColorGroup& colorGroup);
 	void calcRect( const TQString& text_=TQString() );
 	void paintFocus(TQPainter*, const TQColorGroup&) {}
 	bool acceptDrop(const TQMimeSource*) const;
diff --git a/src/gvcore/fileviewcontroller.cpp b/src/gvcore/fileviewcontroller.cpp
index bdacf01..bb57a07 100644
--- a/src/gvcore/fileviewcontroller.cpp
+++ b/src/gvcore/fileviewcontroller.cpp
@@ -191,7 +191,7 @@ public:
 
 	void initFilterBar() {
 		mFilterBar=new FilterBar(that);
-		mFilterBar->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
+		mFilterBar->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
 		mFilterBar->hide();
 
 		TQIconSet resetIS=BarIcon("locationbar_erase");
@@ -256,7 +256,7 @@ FileViewController::FileViewController(TQWidget* parent,KActionCollection* actio
 : TQWidget(parent)
 , mMode(FILE_LIST)
 , mPrefetch( NULL )
-, mChangeDirtqStatus(CHANGE_DIR_STATUS_NONE)
+, mChangeDirStatus(CHANGE_DIR_STATUS_NONE)
 , mBrowsing(false)
 , mSelecting(false)
 {
@@ -338,7 +338,7 @@ FileViewController::FileViewController(TQWidget* parent,KActionCollection* actio
 
 	// Dir lister
 	mDirLister=new DirLister;
-	mDirLister->setMainWindow(tqtopLevelWidget());
+	mDirLister->setMainWindow(topLevelWidget());
 	connect(mDirLister,TQT_SIGNAL(clear()),
 		TQT_TQOBJECT(this),TQT_SLOT(dirListerClear()) );
 
@@ -575,13 +575,13 @@ void FileViewController::slotSelectNext() {
 }
 
 void FileViewController::slotSelectPreviousDir() {
-	mChangeDirtqStatus = CHANGE_DIR_STATUS_PREV;
+	mChangeDirStatus = CHANGE_DIR_STATUS_PREV;
 	mDirLister->clearError();
 	mDirLister->openURL(mDirURL.upURL());
 }
 
 void FileViewController::slotSelectNextDir() {
-	mChangeDirtqStatus = CHANGE_DIR_STATUS_NEXT;
+	mChangeDirStatus = CHANGE_DIR_STATUS_NEXT;
 	mDirLister->clearError();
 	mDirLister->openURL(mDirURL.upURL());
 }
@@ -1102,12 +1102,12 @@ void FileViewController::delayedDirListerCompleted() {
 		mFileThumbnailView->sort(mFileThumbnailView->sortDirection());
 	}
 
-	if (mChangeDirtqStatus != CHANGE_DIR_STATUS_NONE) {
+	if (mChangeDirStatus != CHANGE_DIR_STATUS_NONE) {
 		KFileItem *item;
 		TQString fileName = mDirURL.filename();
 		for (item=currentFileView()->firstFileItem(); item; item=currentFileView()->nextItem(item) ) {
 			if (item->name() == fileName) {
-				if (mChangeDirtqStatus == CHANGE_DIR_STATUS_NEXT) {
+				if (mChangeDirStatus == CHANGE_DIR_STATUS_NEXT) {
 					do {
 						item=currentFileView()->nextItem(item);
 					} while (item && !Archive::fileItemIsDirOrArchive(item));
@@ -1119,7 +1119,7 @@ void FileViewController::delayedDirListerCompleted() {
 				break;
 			};
 		}
-		mChangeDirtqStatus = CHANGE_DIR_STATUS_NONE;
+		mChangeDirStatus = CHANGE_DIR_STATUS_NONE;
 		if (!item) {
 			mDirLister->openURL(mDirURL);
 		} else {
diff --git a/src/gvcore/fileviewcontroller.h b/src/gvcore/fileviewcontroller.h
index de0de53..8339659 100644
--- a/src/gvcore/fileviewcontroller.h
+++ b/src/gvcore/fileviewcontroller.h
@@ -227,7 +227,7 @@ private:
 		CHANGE_DIR_STATUS_NONE,
 		CHANGE_DIR_STATUS_PREV,
 		CHANGE_DIR_STATUS_NEXT
-	} mChangeDirtqStatus;
+	} mChangeDirStatus;
 
 	bool mBrowsing;
 	bool mSelecting;
diff --git a/src/gvcore/filterbar.ui b/src/gvcore/filterbar.ui
index b407ce1..2c9f11c 100644
--- a/src/gvcore/filterbar.ui
+++ b/src/gvcore/filterbar.ui
@@ -64,7 +64,7 @@
             <property name="sizeType">
                 <enum>Maximum</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>16</width>
                     <height>16</height>
@@ -125,7 +125,7 @@ equal to this date</string>
             <property name="sizeType">
                 <enum>Maximum</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>16</width>
                     <height>16</height>
@@ -185,7 +185,7 @@ equal to this date</string>
             <property name="sizeType">
                 <enum>Maximum</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>16</width>
                     <height>16</height>
@@ -210,7 +210,7 @@ equal to this date</string>
             <property name="sizeType">
                 <enum>Expanding</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>16</width>
                     <height>16</height>
diff --git a/src/gvcore/fullscreenbar.cpp b/src/gvcore/fullscreenbar.cpp
index 311b98d..be2b517 100644
--- a/src/gvcore/fullscreenbar.cpp
+++ b/src/gvcore/fullscreenbar.cpp
@@ -83,8 +83,8 @@ FullScreenBar::FullScreenBar(TQWidget* parent)
 	setIconSize(FULLSCREEN_ICON_SIZE);
 	setMovingEnabled(false);
 
-	TQColor bg=tqcolorGroup().highlight();
-	TQColor fg=tqcolorGroup().highlightedText();
+	TQColor bg=colorGroup().highlight();
+	TQColor fg=colorGroup().highlightedText();
 	TQPalette pal(palette());
 	pal.setColor(TQColorGroup::Background, bg);
 	pal.setColor(TQColorGroup::Foreground, fg);
diff --git a/src/gvcore/imageloader.cpp b/src/gvcore/imageloader.cpp
index 06a9011..699d088 100644
--- a/src/gvcore/imageloader.cpp
+++ b/src/gvcore/imageloader.cpp
@@ -113,7 +113,7 @@ public:
 	int getch() {
 		if (mThread->testCancel()) {
 			LOG("cancel detected");
-			setqStatus(IO_ReadError);
+			seStatus(IO_ReadError);
 			return -1;
 		}
 		return TQBuffer::getch();
diff --git a/src/gvcore/printdialogpagebase.ui b/src/gvcore/printdialogpagebase.ui
index 6d92eda..543877c 100644
--- a/src/gvcore/printdialogpagebase.ui
+++ b/src/gvcore/printdialogpagebase.ui
@@ -98,7 +98,7 @@
                     <property name="sizeType">
                         <enum>Expanding</enum>
                     </property>
-                    <property name="tqsizeHint">
+                    <property name="sizeHint">
                         <size>
                             <width>101</width>
                             <height>21</height>
@@ -186,7 +186,7 @@
                             <property name="sizeType">
                                 <enum>Fixed</enum>
                             </property>
-                            <property name="tqsizeHint">
+                            <property name="sizeHint">
                                 <size>
                                     <width>20</width>
                                     <height>20</height>
@@ -214,7 +214,7 @@
                             <property name="sizeType">
                                 <enum>Expanding</enum>
                             </property>
-                            <property name="tqsizeHint">
+                            <property name="sizeHint">
                                 <size>
                                     <width>240</width>
                                     <height>21</height>
@@ -252,7 +252,7 @@
                             <property name="sizeType">
                                 <enum>Fixed</enum>
                             </property>
-                            <property name="tqsizeHint">
+                            <property name="sizeHint">
                                 <size>
                                     <width>20</width>
                                     <height>20</height>
@@ -351,7 +351,7 @@
                             <property name="sizeType">
                                 <enum>Expanding</enum>
                             </property>
-                            <property name="tqsizeHint">
+                            <property name="sizeHint">
                                 <size>
                                     <width>16</width>
                                     <height>20</height>
diff --git a/src/gvcore/qxcfi.cpp b/src/gvcore/qxcfi.cpp
index 9fb146a..27ad0b9 100644
--- a/src/gvcore/qxcfi.cpp
+++ b/src/gvcore/qxcfi.cpp
@@ -486,7 +486,7 @@ void XCFImageFormat::readXCF ( TQImageIO* image_io )
   }
 
   image_io->setImage( xcf_image.image );
-  image_io->setqStatus( 0 );
+  image_io->seStatus( 0 );
 }
 
 /*!
diff --git a/src/gvcore/thumbnaildetailsdialogbase.ui b/src/gvcore/thumbnaildetailsdialogbase.ui
index 1dd6646..e9ef011 100644
--- a/src/gvcore/thumbnaildetailsdialogbase.ui
+++ b/src/gvcore/thumbnaildetailsdialogbase.ui
@@ -45,7 +45,7 @@
                     <property name="sizeType">
                         <enum>Fixed</enum>
                     </property>
-                    <property name="tqsizeHint">
+                    <property name="sizeHint">
                         <size>
                             <width>21</width>
                             <height>20</height>
@@ -96,7 +96,7 @@
             <property name="sizeType">
                 <enum>Fixed</enum>
             </property>
-            <property name="tqsizeHint">
+            <property name="sizeHint">
                 <size>
                     <width>21</width>
                     <height>21</height>
diff --git a/src/gvcore/xpm.cpp b/src/gvcore/xpm.cpp
index cc2cabc..b56ba59 100644
--- a/src/gvcore/xpm.cpp
+++ b/src/gvcore/xpm.cpp
@@ -74,7 +74,7 @@ static TQString fbname( const TQString &fileName ) // get file basename (sort of
 	    s = s.mid( i );
 	if ( (i = s.findRev('\\')) >= 0 )
 	    s = s.mid( i );
-	TQRegExp r( TQString::tqfromLatin1("[a-zA-Z][a-zA-Z0-9_]*") );
+	TQRegExp r( TQString::fromLatin1("[a-zA-Z][a-zA-Z0-9_]*") );
 	int p = r.search( s );
 	if ( p == -1 )
 	    s.truncate( 0 );
@@ -82,7 +82,7 @@ static TQString fbname( const TQString &fileName ) // get file basename (sort of
 	    s = s.mid( p, r.matchedLength() );
     }
     if ( s.isEmpty() )
-	s = TQString::tqfromLatin1( "dummy" );
+	s = TQString::fromLatin1( "dummy" );
     return s;
 }
 
@@ -161,10 +161,10 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
     int i, cpp, ncols, w, h, index = 0;
 
     if ( iio ) {
-	iio->setqStatus( 1 );
+	iio->seStatus( 1 );
 	d = iio ? iio->ioDevice() : 0;
 	d->readLine( buf.data(), buf.size() );	// "/* XPM */"
-	TQRegExp r( TQString::tqfromLatin1("/\\*.XPM.\\*/") );
+	TQRegExp r( TQString::fromLatin1("/\\*.XPM.\\*/") );
 	if ( buf.find(r) == -1 )
 	    return;					// bad magic
     } else if ( !source ) {
@@ -291,7 +291,7 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
     }
     if ( iio ) {
 	iio->setImage( image );
-	iio->setqStatus( 0 );			// image ok
+	iio->seStatus( 0 );			// image ok
     }
 }
 
@@ -340,7 +340,7 @@ static const char* xpm_color_name( int cpp, int index )
 static void write_xpm_image( TQImageIO * iio )
 {
     if ( iio )
-	iio->setqStatus( 1 );
+	iio->seStatus( 1 );
     else
 	return;
 
@@ -424,7 +424,7 @@ static void write_xpm_image( TQImageIO * iio )
     }
     s << "};" << endl;
 
-    iio->setqStatus( 0 );
+    iio->seStatus( 0 );
 }
 
 // TQt code end ---------------------------
diff --git a/src/tsthread/tsthread.cpp b/src/tsthread/tsthread.cpp
index 6363f2e..c845cce 100644
--- a/src/tsthread/tsthread.cpp
+++ b/src/tsthread/tsthread.cpp
@@ -175,7 +175,7 @@ void TSThread::customEvent( TQCustomEvent* ev )
         }
     bool deleted = false;
     deleted_flag = &deleted; // this is like TQGuardedPtr for self, but faster
-    int signal_id = e->object->tqmetaObject()->findSignal( normalizeSignalSlot( e->signal ).data() + 1, true );
+    int signal_id = e->object->metaObject()->findSignal( normalizeSignalSlot( e->signal ).data() + 1, true );
     if( signal_id >= 0 )
         e->object->qt_emit( signal_id, e->args );
     else
diff --git a/src/gvcore/imageview.cpp b/src/gvcore/imageview.cpp
index a6c5b9f..f9da66f 100644
--- a/src/gvcore/imageview.cpp
+++ b/src/gvcore/imageview.cpp
@@ -1350,7 +1350,7 @@ double ImageView::computeZoomToWidth() const {
 	if (d->mDocument->isNull()) {
 		return 1.0;
 	}
-	int sw = verticalScrollBar()->tqsizeHint().width(); // tqgeometry is not valid before first show()
+	int sw = verticalScrollBar()->sizeHint().width(); // tqgeometry is not valid before first show()
 	int w = width();
 	int dw = d->mDocument->width();
 	switch( vScrollBarMode()) {
@@ -1370,7 +1370,7 @@ double ImageView::computeZoomToHeight() const {
 	if (d->mDocument->isNull()) {
 		return 1.0;
 	}
-	int sh = horizontalScrollBar()->tqsizeHint().height();
+	int sh = horizontalScrollBar()->sizeHint().height();
 	int h = height();
 	int dh = d->mDocument->height();
 	switch( vScrollBarMode()) {
@@ -1425,11 +1425,11 @@ void ImageView::updateImageOffset() {
 	int zpixHeight=int(d->mDocument->height() * d->mZoom);
 
 	if (zpixWidth>viewWidth && hScrollBarMode()!=AlwaysOff) {
-		// use tqsizeHint() - tqgeometry is not valid before first show()
-		viewHeight-=horizontalScrollBar()->tqsizeHint().height();
+		// use sizeHint() - tqgeometry is not valid before first show()
+		viewHeight-=horizontalScrollBar()->sizeHint().height();
 	}
 	if (zpixHeight>viewHeight && vScrollBarMode()!=AlwaysOff) {
-		viewWidth-=verticalScrollBar()->tqsizeHint().width();
+		viewWidth-=verticalScrollBar()->sizeHint().width();
 	}
 
 	d->mXOffset=TQMAX(0,(viewWidth-zpixWidth)/2);